"""
Universal Directory Tree Widget
"""

from textual.widgets import DirectoryTree
from upath import UPath


class UniversalDirectoryTree(DirectoryTree):
    """
    Universal Directory Tree Widget
    """

    PATH = UPath
